;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xd3ca337e2ed0be21322b54c856911748 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x05dc546ea537ec0f598df1220d10d7e2 . "./code.cg2js/cg-printing.fasl")
(#x2e68ed420cc3637afd344cb929029ee4 . "./code.cg2js/cg-caret.fasl")
(#xf82073b9d47b58ce7f8882ad675f2290 . "./code.cg2js/cg-item-list.fasl")
(#x2e7a4e84487171d199d91026217ca579 . "./code.cg2js/cg-progress-indicator.fasl")
(#x28152ae7f3d80d39bf8a18067809aa64 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x6aa169f2450b1802b9077a2d7a83b2eb . "./code.cg2js/cg-outline.fasl")
(#xd4755f3826e503ba983cad497ab3812a . "./code.cg2js/cg-palette.fasl")
(#x582147a38bb4a2240581edc5356e0fc3 . "./code.cg2js/cg-selected-object.fasl")
(#xf15837857be5facb323686565d13f28a . "./code.cg2js/cg-status-bar.fasl")
(#x148d2fcf99d43f4b7b5d4b6e079e181f . "./code.cg2js/cg-wrap-string.fasl")
(#x910a47b92ffaa44e1433891fec51321b . "./code.cg2js/cg-fill-texture.fasl")
(#xe8c4a40f6a52bf7be050c8561496ac4d . "./code.cg2js/cg-layout.fasl")
(#x4d7e837a75ccb3b71cc331abec6c45df . "./code.cg2js/cg-timer.fasl")
(#x27594cf019e42f2cb6f1e70c628eb8d4 . "./code.cg2js/cg-dialog-item.fasl")
(#x53f83caa1f005a1deb01b816d43d654f . "./code.cg2js/cg-button.fasl")
(#xdafbb7edae982f629ca801cc9a7e2aab . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xaf2680ada0684238752d5998d4f7d9e8 . "./code.cg2js/cg-tray.fasl")
(#x3d6f62481446b508a85c888fc99fcecc . "./code.cg2js/cg-plot-widget.fasl")
(#x86ee3d99a3554117a6926c32ac6da9dc . "./code.cg2js/cg-pixmap.fasl")
(#xdf8a308c26804f53a0709e5f2904d019 . "./code.cg2js/cg-font-dialog.fasl")
(#xe8b2d2294b6e5f3298320f5605396aea . "./code.cg2js/cg-os-widget.fasl")
(#x58fe353b893c5d271e5dc8fc7541d605 . "./code.cg2js/cg-text-or-combo.fasl")
(#xacaad8f8507fd127ef4ffc6d88b54f4b . "./code.cg2js/cg-trackbar.fasl")
(#xa3fe03982d320ceceb5ddf03271aa699 . "./code.cg2js/cg-up-down-control.fasl")
(#xf8dba76a4bd823a357eda952c4f6d45e . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x80f3f82dda65d5262d30b7a296dd9901 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xd83ceccb59b75e0c3e7bc9a95e1869c0 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xe8926bf3bdcc2de0ee53812ab54f6ee3 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x235da082e1322defb1b0c999da2af599 . "./code.cg2js/cg-chart-widget.fasl")
(#x735b054a05e0b7d871e90249026fd50c . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xd933bfe32beb5f8767677c9e24c63a8a . "./code.cg2js/cg-group-box.fasl")
(#xab64ecd10431cfee72cb7a52ffadd7d2 . "./code.cg2js/cg-static-text.fasl")
(#xb6d2b2dea75afdbbc0754adebdb23308 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xefa0dc20a781613126730283ee194b51 . "./code.cg2js/cg-color-dialog.fasl")
(#x61fa7d8bea8d607b3a1b6a6efe1279d4 . "./code.cg2js/cg-intersect.fasl")
(#xc82203ef5dffc5505308b870ab12059d . "./code.cg2js/cg-gesture-emulation.fasl")
(#x6c4466e307d40830d734fc22c1f9ab42 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xf7cb440f44517f3d0a6efb8e65ef13bb . "./code.cg2js/cg-html-dialog.fasl")
(#xf8cb98711abf8bfbfda72c762e0fc3c1 . "./code.cg2js/cg-lettered-menu.fasl")
(#xce556b1145fcb3f0213d961d76419764 . "./code.cg2js/cg-class-grid.fasl")
(#xf2ec022f8c53e9a71a91b8d32c4fe466 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xdf63978b8ccfd5ccbe06ed0345b6b316 . "./code.cg2js/cg-calendar.fasl")
(#xd35324d195843eef1cd3bb7bcecc699d . "./code.cg2js/cg-editable-text.fasl")
(#x799a86a0eea4aee4b3e4a18e08c94219 . "./code.cg2js/cg-property.fasl")
(#xa09b1ffba10ee7c01f2c24223420972c . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x02957a90e1d75b816b4d154ce7cb570f . "./code.cg2js/cg-grid-widget.fasl")
(#x2a708eee2bbc68d2db5242bf67de91da . "./code.cg2js/cg-paren-matching.fasl")
(#xb7187a191916e924b0ec692ff3139f9b . "./code.cg2js/cg-dev.fasl")
(#x35268d49d4f585a0f97242d4a39cacbd . "./code.cg2js/cg-drawable.fasl")
(#x38f6106a4ef8f5cea0b9766ebf14fb0a . "./code.cg2js/cg-curve.fasl")
(#x21fb83619c1eca8b875bba0a2b83182a . "./code.cg2js/cg-lisp-widget.fasl")
(#xbc5b178df47a4d38c06ca1c4248f04b9 . "./code.cg2js/cg-dde-utils.fasl")
(#xf48342b498bdde2f6e82cb735b96b5b1 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x9b17ef8c0b6d87037f14f8c282606a79 . "./code.cg2js/cg-object-editor-layout.fasl")
(#x067f47badafd33831e99e12ae8a2904c . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xf1dfed2355beb1096cd39922b62f28bc . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x5d00cc7447a2f0529e0f4dd12baadb0e . "./code.cg2js/cg-lamp.fasl")
(#x1a31743856ec3f7caba5633be6cc5a52 . "./code.cg2js/cg-common-control.fasl")
(#x390ffe0722ec901c266798314737629a . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x39b6982612d3b7d8f659f0d377a3c816 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x8a1777327e448cea76b5855d1ece93ce . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#x93c5c6a313634aa3f5f0c02bc5903e18 . "./code.cg2js/cg-project-window.fasl")
(#xc31bce55f11e95af0fe09ca8220a4f74 . "./code.cg2js/cg-sample-file-menu.fasl")
(#xdf29e107996bb9d2c940a33bce1a0ce0 . "./code.cg2js/cg-class-support.fasl")
(#x51698981f81a27d2dd2b0f5a3c91916c . "./code.cg2js/cg-multi-picture-button.fasl")
(#xeb1f0e7ae39dd9495b0c9defe3668881 . "./code.cg2js/cg-yes-no-list.fasl")
(#x08ac6385d9b5f7c59bfa6e619d404917 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x8f0fcebe9b7c9233a16d350bb49b8f2c . "./code.cg2js/cg-string-dialog.fasl")
(#x0286c0fe96cbc394a6a0205ec2c7149e . "./code.cg2js/cg-menu-tooltip.fasl")
(#x78173ffde3f8a91e1ba8e9d042b3e327 . "./code.cg2js/cg-dropping-outline.fasl")
(#x10a0934044c71f0eb6b42475bc3145ae . "./code.cg2js/cg.fasl")
(#xff851a136bb19f3b0958a520611b88f8 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x2dd1cb883ca6cb987a06945b841b4683 . "./code.cg2js/cg-scaling-stream.fasl")
(#xc0bbb70d02dc86fbe872a6e1496d0cf8 . "./code.cg2js/cg-yes-no-string.fasl")
(#xe6bd7646fbebc2606bc6770271a752c1 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x4d07fbcbff7230221489ad6f0f64988c . "./code.cg2js/cg-web-browser.fasl")
(#xae84b88aa95c6ef7255dd9dc0021ff12 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x32d7dea512a3823f38343bfc1cb3d1a0 . "./code.cg2js/cg-drag-and-drop.fasl")
(#xeae716d4af6fc5cc4192eb074dcf5a0b . "./code.cg2js/cg-message-dialog.fasl")
(#xfc84a209c4e173680d001c81c7a4f9e4 . "./code.cg2js/cg-comtab.fasl")
(#xeb40e6818f844426ab4779e946c189e6 . "./code.cg2js/cg-base.fasl")
(#x9749add4c156b7626569eb44757c4439 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xc53e159797868466ef0952a067dee374 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xad2e496ae0c5b96cbc20a03b19c49da0 . "./code.cg2js/cg-text-edit-pane.fasl")
(#x0136c9eae15635d64b48560f7fcbcd34 . "./code.cg2js/cg-utility-dialog.fasl")
(#x4841d3e71e4595633178370fe88c8faa . "./code.cg2js/cg-object-editor.fasl")
(#x113536990f494300131f6f111d0d5cb8 . "./code.cg2js/cg-edit-in-place.fasl")
(#x30580ad20eb47b61428e795483bf0284 . "./code.cg2js/cg-radio-button.fasl")
(#x13edc76b0a325221618fb7cc30fd3dba . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xc3d56d9aab1ca1aae9ae829baf5647c7 . "./code.cg2js/cg-nodes.fasl")
(#xbce5eabe541e0927a6e12a0132430b2c . "./code.cg2js/cg-get-position.fasl")
(#x1619b9c9620435c597c23b81539d9a21 . "./code.cg2js/cg-directory-dialog.fasl")
(#x2c7b14f2a12565b3cd9f06fd619c1767 . "./code.cg2js/cg-lisp-text.fasl")
(#x09788a6768657d97c5929d2d2caa786e . "./code.cg2js/cg-combo-box.fasl")
(#x8e477dda0b8854c5e7175b45ba4a8c7b . "./code.cg2js/cg-text-widget.fasl")
(#x5c608b288767e00a5afaf7edf98db830 . "./code.cg2js/cg-list-view.fasl")
(#xd986a21758f688d8a5364dad7a8fafdf . "./code.cg2js/cg-header-control.fasl")
(#xfd7f215c8dbee3c8565dfd4947e5efca . "./code.cg2js/cg-graphics-context.fasl")
(#x72c7c00bb71899fc3477ae16000fe1cb . "./code.cg2js/cg-get-pixmap.fasl")
(#x4ecedfa89ff869223298e7eae3aaeece . "./code.cg2js/cg-menu.fasl")
(#x5973f8c6b1a0938a8b3a2d8e69832b2f . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x87eed3881a372497c43665e686c07d2d . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xb72ed8bbcc941ad8f31e3cb3453608ac . "./code.cg2js/cg-tooltip.fasl")
(#x7328777d52d82685c5e2d519f0ab6f4a . "./code.cg2js/cg-html-widget.fasl")
(#x3563f45ed22be6ae65e16e034fa73386 . "./code.cg2js/cg-choice-list.fasl")
(#xe64dcb93237ea80878d3e28da9001523 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x13362838316d8c6d7293009cdb39930a . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x21d2679e70be86b047d69c8d1a6d1bb3 . "./code.cg2js/cg-icon.fasl")
(#x91e9b5aef5b4dd233212c7ca68a10c07 . "./code.cg2js/cg-acache.fasl")
(#x7d2638757781a44d09903a34656f62e4 . "./code.cg2js/cg-template-string.fasl")
(#xd1ba2f79b4e2bee83a3c3db63901462e . "./code.cg2js/cg-bitmap-pane.fasl")
(#xb28c783be4f1889f631447ce475b7ec8 . "./code.cg2js/cg-toggling-widget.fasl")
(#x6df53e96292b8f59a824ff32d2bd63a2 . "./code.cg2js/cg-tab-control.fasl")
(#x0ca3dcb936bceab380cc3116d85d5b37 . "./code.cg2js/cg-split-bar.fasl")
(#xc524628f8f066300257c87230c6df8e0 . "./code.cg2js/cg-picture-widget.fasl")
(#x591bbb88ed94b2458322d968cf3f758c . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x504d505fb9ef2b2dafe9dc862de004ed . "./code.cg2js/cg-choose-printer.fasl")
(#xd49310a027ea319feaa181f1225f038b . "./code.cg2js/cg-os-window.fasl")
(#xa166a9476b1aaf6b25e91aaafed4e508 . "./code.cg2js/cg-scroll-bar.fasl")
(#xa470bd61715b0aa332b636c654fb45cf . "./code.cg2js/cg-clipboard.fasl")
(#x180e4a79fdad1594f3b253675562cd80 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x5562c78be7a6561a3e02ade33ee8f41d . "./code.cg2js/cg-hotspot.fasl")
(#x77482345b0c34cab6f29422983f179e2 . "./code.cg2js/cg-rich-edit.fasl")
(#x9c13b43279ed0bde3054b2baa2f63767 . "./code.cg2js/cg-check-box.fasl")
(#x3a55c03a680c7d392a3a378fe2314318 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x85e102fd66f736b82dadade67c020762 . "./code.cg2js/cg-file-dialog.fasl")
(#xcc77e3612847ecda4e43901e45296ae0 . "./code.cg2js/cg-toolbar.fasl")
(#xeb69c9abbaaf84f8921657a784f8b60d . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xdfd341d4113a618735c495ecc28a7b7b . "./code.cg2js/cg-chart-or-plot.fasl")
(#x73118a6e317a9e26ade559723a4a7c3d . "./code.cg2js/cg-shortcut-menu.fasl")
(#x08563b7d746a30a243df3771155ea0a4 . "./code.idejs/ide-project.fasl")
(#x3a02b5237cf85295804ecdc3dacc56a8 . "./code.idejs/ide-intro.fasl")
(#x89b8f677fd120810f90e46f43a83cf49 . "./code.idejs/ide-find-in-files.fasl")
(#xf722d2bbf1fe1694242199b4472fa874 . "./code.idejs/ide-grapher.fasl")
(#xd761ff5df5b32bc90336f74f5c983d37 . "./code.idejs/ide-inspector.fasl")
(#x8603eb553a242a4b03fd27bffd49f321 . "./code.idejs/ide-editor.fasl")
(#xccfaca55aabc72e658c6f119ce36ed5e . "./code.idejs/ide-window-list.fasl")
(#x8232a8b34c2791527382b1d20b34e62a . "./code.idejs/ide-process-browser.fasl")
(#x2c50d4a917a1c2ecf645311ac97b3e13 . "./code.idejs/ide-patch-dialog.fasl")
(#xdf638efbba13292342f5f2b4bbca3da6 . "./code.idejs/ide-class-grapher.fasl")
(#xea2c8c6414d9713462d6fb76685787f9 . "./code.idejs/ide-base.fasl")
(#x997982dc833c3d187d5daa4d34e44751 . "./code.idejs/ide.fasl")
(#xdb2d6306d494d9368abb7958450720ec . "./code.idejs/ide-trace.fasl")
(#x68086fbcca9d83a44b151bf48b882ce9 . "./code.idejs/ide-form.fasl")
(#x62da7b42cfdd357bc4534199ed1d062e . "./code.idejs/ide-find-definitions.fasl")
(#xcd8ed6b0739cbadd5ac2677c8133ebe3 . "./code.idejs/ide-apropos.fasl")
(#x8cb4b024138e1cdc6c57171e8ec55be0 . "./code.idejs/ide-class-browser.fasl")
(#xaa0be73903e2d58f4a71854d0a54b1ea . "./code.idejs/ide-navigator.fasl")
(#x211b5c188abc5cf1e096f4305863e012 . "./code.idejs/ide-clipboard.fasl")
(#x6275339278ac62a41c45c2996d7a2952 . "./code.idejs/ide-acache.fasl")
(#xc020fa3412d4ed0a941f4b240617b38f . "./code.idejs/ide-keyshort.fasl")
(#xcaeae7a2473f08898ead10ae21d75ca3 . "./code.idejs/ide-package-list.fasl")
(#x783099e7cddefb6656dbcec2922693ef . "./code.idejs/ide-dev.fasl")
(#x785b009207cd19fe54c93fc535e484ec . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
